{"cells": [{"cell_type": "markdown", "id": "97c36684", "metadata": {}, "source": ["# Geometric properties:  NO$_3\\cdot$ radical\n", "\n", "In this set of exercises, you will assess the performance of various\n", "state-of-the-art density functionals in the prediction of geometric\n", "properties, and you will again compare your results to both wavefunction\n", "theory and experimental data. \n", "\n", "## Structural Parameters of NO$_3\\cdot$: Performance of DFT, HF and MP2\n", "\n", "Before diving into the theoretical aspects of exchange-correlation\n", "functionals, you will put a representative selection of functionals to\n", "good use in a notoriously tricky system, the NO$_3\\cdot$ radical.\n", "Nitrite radicals are highly reactive species that are rapidly destroyed\n", "by sunlight, but as the sun sets, they start to play an important role\n", "in chemical transformations (in what is called the night-time chemistry\n", "of the atmosphere). [Ref: [*Phys. Chem. Chem. Phys.*, **2014**, 16, *19437-19445*](https://pubs.rsc.org/en/content/articlehtml/2014/cp/c4cp02792b)] \n", "\n", "There exist various experimental and theoretical\n", "studies of NO$_3\\cdot$ , with the experiment indicating a fully symmetric D$_3^h$\n", "structure with equal N-O bond lengths of 1.24 \u00c5 and O-N-O bond angles of\n", "120$^\\circ$. \n", "\n", "In this exercise, you will be comparing the performance of\n", "various DFT exchange-correlation functionals, Hartree-Fock theory and\n", "MP2 in predicting these structural parameters.\n"]}, {"cell_type": "markdown", "id": "28914169", "metadata": {}, "source": ["First, we'll import the required modules and set Psi4 parameters."]}, {"cell_type": "code", "execution_count": 1, "id": "aff8393e", "metadata": {}, "outputs": [{"name": "stdout", "output_type": "stream", "text": ["  Threads set to 2 by Python driver.\n", "\n", "  Memory set to   1.863 GiB by Python driver.\n"]}, {"data": {"text/plain": ["2000000000"]}, "execution_count": 1, "metadata": {}, "output_type": "execute_result"}], "source": ["import psi4\n", "import pandas as pd\n", "\n", "import sys\n", "sys.path.append(\"..\")\n", "\n", "from helpers import *\n", "\n", "psi4.set_num_threads(2)\n", "psi4.set_memory('2 GB')"]}, {"cell_type": "markdown", "id": "3c036972", "metadata": {}, "source": ["This is our starting geometry."]}, {"cell_type": "code", "execution_count": 2, "id": "f080b9d4", "metadata": {}, "outputs": [], "source": ["radical = psi4.geometry(\"\"\"\n", "symmetry c1\n", "0 2\n", " N     0.000000     0.000000     0.000000\n", " O     1.400000     0.000000     0.000000\n", " O    -1.000000     1.000000     0.000000\n", " O    -1.000000    -1.000000     0.000000\n", "\"\"\")"]}, {"cell_type": "code", "execution_count": 3, "id": "9f19a069", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_16696478703548574\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_16696478703548574\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_16696478703548574 = null;\nvar warn = document.getElementById(\"3dmolwarning_16696478703548574\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_16696478703548574 = $3Dmol.createViewer($(\"#3dmolviewer_16696478703548574\"),{backgroundColor:\"white\"});\nviewer_16696478703548574.zoomTo();\n\tviewer_16696478703548574.addModel(\"4\\n\\n N    0.000000000000   -0.000000000000    0.154819916277\\n O    0.000000000000   -0.000000000000    1.554819916277\\n O    0.000000000000   -1.000000000000   -0.845180083723\\n O    0.000000000000    1.000000000000   -0.845180083723\\n\",\"xyz\");\n\tviewer_16696478703548574.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_16696478703548574.zoomTo();\nviewer_16696478703548574.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_16696478703548574\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_16696478703548574\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_16696478703548574 = null;\n", "var warn = document.getElementById(\"3dmolwarning_16696478703548574\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_16696478703548574 = $3Dmol.createViewer($(\"#3dmolviewer_16696478703548574\"),{backgroundColor:\"white\"});\n", "viewer_16696478703548574.zoomTo();\n", "\tviewer_16696478703548574.addModel(\"4\\n\\n N    0.000000000000   -0.000000000000    0.154819916277\\n O    0.000000000000   -0.000000000000    1.554819916277\\n O    0.000000000000   -1.000000000000   -0.845180083723\\n O    0.000000000000    1.000000000000   -0.845180083723\\n\",\"xyz\");\n", "\tviewer_16696478703548574.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_16696478703548574.zoomTo();\n", "viewer_16696478703548574.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ(radical)"]}, {"cell_type": "markdown", "id": "c12810c1", "metadata": {}, "source": ["We will perform calculations at HF, MP2 and DFT level. We will also visualize MP2 and DFT orbitals and compare them (see **Visualizing the orbitals** subsections of **MP2** and **DFT** sections)."]}, {"cell_type": "markdown", "id": "e47c5190", "metadata": {}, "source": ["### HF"]}, {"cell_type": "markdown", "id": "d64a469c", "metadata": {}, "source": ["First, we'll do a Hartree Fock calculation. As this is a difficult system we make use of a second order SCF (SOSCF) convergence method implemented in Psi4. \n", "\n", "SOSCF makes use of the fact that the energy that we want to minimize in the SCF calculation has a gradient (and a hessian) both with respect to geometry changes and orbital changes. \n", "In a standard SCF calculation as you get close to convergence the orbital changes will be very small.  When using SOSCF, Psi4 uses the orbital hessian to make the next orbital step when performing the SCF calculation. In the code, the energy is written as a taylor expansion of orbitals and truncated for all terms higher than second order. This helps in converging tricky systems but requires that one is already close to a minimum. So by setting `soscf` to `true` by default the soscf procedure is switched on when the gradient RMS is below $1.0 \\times 10^{-2}$. By specifying `soscf_max_iter` we increase the number of SOSCF steps from the default of 5 to 20. "]}, {"cell_type": "code", "execution_count": null, "id": "ae735042", "metadata": {}, "outputs": [], "source": ["method = \"hf\"\n", "\n", "psi4.core.set_output_file(f'radical_opt_{method}.log', False)\n", "psi4.set_options({'reference':'uhf','guess':'gwh', 'soscf':True, 'soscf_max_iter':20,'maxiter':200})\n", "E_hf = psi4.optimize('hf/6-31+G*', molecule=radical)\n", "E_hf"]}, {"cell_type": "markdown", "id": "67b04bbf", "metadata": {}, "source": ["### MP2"]}, {"cell_type": "code", "execution_count": null, "id": "41358925", "metadata": {}, "outputs": [], "source": ["method = \"mp2\"\n", "\n", "\n", "psi4.core.clean_options()\n", "psi4.core.set_output_file(f'radical_opt_{method}.log', False)\n", "psi4.set_options({'reference':'uhf','guess':'read', 'mp2_type':'conv', 'maxiter':200, 'soscf':True, 'soscf_max_iter':20})\n", "E_mp2, wfn = psi4.optimize(f'{method}/6-31+G*', molecule=radical, return_wfn=True)\n", "\n", "E_mp2"]}, {"cell_type": "markdown", "id": "e1dfcda1", "metadata": {}, "source": ["### Geometrical parameters\n", "Let's have a look at the geometrical parameters predicted by MP2 calculation. The following cell uses the `calculate_bond` and `calculate_angle` helper functions for that. The atom numbering can be checked with another helper function, `drawXYZ_labeled`."]}, {"cell_type": "code", "execution_count": null, "id": "4cc5d38e", "metadata": {}, "outputs": [], "source": ["# Convert molecule coordinates to numpy array\n", "r_numpy = radical.to_arrays()[0]*hartree2A \n", "\n", "print('MP2 values')\n", "print(f'r1: {calculate_bond(r_numpy[0], r_numpy[1]):.3f}')\n", "print(f'r2: {calculate_bond(r_numpy[0], r_numpy[3]):.3f}')\n", "print(f'r3: {calculate_bond(r_numpy[0], r_numpy[2]):.3f}')\n", "print(f'O-N-O angle: {calculate_angle(r_numpy[1], r_numpy[0], r_numpy[2]):.3f}')\n", "print(f'O-N-O angle: {calculate_angle(r_numpy[3], r_numpy[0], r_numpy[2]):.3f}')"]}, {"cell_type": "code", "execution_count": 17, "id": "d95561f3", "metadata": {}, "outputs": [{"data": {"application/3dmoljs_load.v0": "<div id=\"3dmolviewer_16696487402565973\"  style=\"position: relative; width: 400px; height: 400px\">\n        <p id=\"3dmolwarning_16696487402565973\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n        </div>\n<script>\n\nvar loadScriptAsync = function(uri){\n  return new Promise((resolve, reject) => {\n    var tag = document.createElement('script');\n    tag.src = uri;\n    tag.async = true;\n    tag.onload = () => {\n      resolve();\n    };\n  var firstScriptTag = document.getElementsByTagName('script')[0];\n  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n});\n};\n\nif(typeof $3Dmolpromise === 'undefined') {\n$3Dmolpromise = null;\n  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n}\n\nvar viewer_16696487402565973 = null;\nvar warn = document.getElementById(\"3dmolwarning_16696487402565973\");\nif(warn) {\n    warn.parentNode.removeChild(warn);\n}\n$3Dmolpromise.then(function() {\nviewer_16696487402565973 = $3Dmol.createViewer($(\"#3dmolviewer_16696487402565973\"),{backgroundColor:\"white\"});\nviewer_16696487402565973.zoomTo();\n\tviewer_16696487402565973.addModel(\"4\\n\\n N   -0.000000000523    0.000000000000    0.107190999173\\n O   -0.000000000002    0.000000000000   -1.281165577292\\n O    1.116078441703    0.000000000000    0.593661514904\\n O   -1.116078441244    0.000000000000    0.593661517446\\n\",\"xyz\");\n\tviewer_16696487402565973.addLabel(\"0\",{\"position\": {\"x\": -5.233422280271299e-10, \"y\": 0.0, \"z\": 0.10719099917342248}, \"inFront\": true});\n\tviewer_16696487402565973.addLabel(\"1\",{\"position\": {\"x\": -1.66770949868278e-12, \"y\": 0.0, \"z\": -1.281165577294602}, \"inFront\": true});\n\tviewer_16696487402565973.addLabel(\"2\",{\"position\": {\"x\": 1.116078441706032, \"y\": 0.0, \"z\": 0.5936615149050014}, \"inFront\": true});\n\tviewer_16696487402565973.addLabel(\"3\",{\"position\": {\"x\": -1.1160784412461937, \"y\": 0.0, \"z\": 0.5936615174473645}, \"inFront\": true});\n\tviewer_16696487402565973.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_16696487402565973.setStyle({\"model\": 0},{\"stick\": {\"colorscheme\": \"yellowCarbon\"}, \"sphere\": {\"scale\": 0.1}});\n\tviewer_16696487402565973.zoomTo();\nviewer_16696487402565973.render();\n});\n</script>", "text/html": ["<div id=\"3dmolviewer_16696487402565973\"  style=\"position: relative; width: 400px; height: 400px\">\n", "        <p id=\"3dmolwarning_16696487402565973\" style=\"background-color:#ffcccc;color:black\">You appear to be running in JupyterLab (or JavaScript failed to load for some other reason).  You need to install the 3dmol extension: <br>\n", "        <tt>jupyter labextension install jupyterlab_3dmol</tt></p>\n", "        </div>\n", "<script>\n", "\n", "var loadScriptAsync = function(uri){\n", "  return new Promise((resolve, reject) => {\n", "    var tag = document.createElement('script');\n", "    tag.src = uri;\n", "    tag.async = true;\n", "    tag.onload = () => {\n", "      resolve();\n", "    };\n", "  var firstScriptTag = document.getElementsByTagName('script')[0];\n", "  firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);\n", "});\n", "};\n", "\n", "if(typeof $3Dmolpromise === 'undefined') {\n", "$3Dmolpromise = null;\n", "  $3Dmolpromise = loadScriptAsync('https://cdn.jsdelivr.net/npm/3dmol@latest/build/3Dmol-min.min.js');\n", "}\n", "\n", "var viewer_16696487402565973 = null;\n", "var warn = document.getElementById(\"3dmolwarning_16696487402565973\");\n", "if(warn) {\n", "    warn.parentNode.removeChild(warn);\n", "}\n", "$3Dmolpromise.then(function() {\n", "viewer_16696487402565973 = $3Dmol.createViewer($(\"#3dmolviewer_16696487402565973\"),{backgroundColor:\"white\"});\n", "viewer_16696487402565973.zoomTo();\n", "\tviewer_16696487402565973.addModel(\"4\\n\\n N   -0.000000000523    0.000000000000    0.107190999173\\n O   -0.000000000002    0.000000000000   -1.281165577292\\n O    1.116078441703    0.000000000000    0.593661514904\\n O   -1.116078441244    0.000000000000    0.593661517446\\n\",\"xyz\");\n", "\tviewer_16696487402565973.addLabel(\"0\",{\"position\": {\"x\": -5.233422280271299e-10, \"y\": 0.0, \"z\": 0.10719099917342248}, \"inFront\": true});\n", "\tviewer_16696487402565973.addLabel(\"1\",{\"position\": {\"x\": -1.66770949868278e-12, \"y\": 0.0, \"z\": -1.281165577294602}, \"inFront\": true});\n", "\tviewer_16696487402565973.addLabel(\"2\",{\"position\": {\"x\": 1.116078441706032, \"y\": 0.0, \"z\": 0.5936615149050014}, \"inFront\": true});\n", "\tviewer_16696487402565973.addLabel(\"3\",{\"position\": {\"x\": -1.1160784412461937, \"y\": 0.0, \"z\": 0.5936615174473645}, \"inFront\": true});\n", "\tviewer_16696487402565973.setStyle({\"stick\": {}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_16696487402565973.setStyle({\"model\": 0},{\"stick\": {\"colorscheme\": \"yellowCarbon\"}, \"sphere\": {\"scale\": 0.1}});\n", "\tviewer_16696487402565973.zoomTo();\n", "viewer_16696487402565973.render();\n", "});\n", "</script>"]}, "metadata": {}, "output_type": "display_data"}], "source": ["drawXYZ_labeled(radical)"]}, {"cell_type": "markdown", "id": "a60f2ba1", "metadata": {"tags": []}, "source": ["### Visualizing the orbitals\n", "\n", "In order to assess the reliability of an electronic structure\n", "calculation, it is usually not sufficient to simply glance at the\n", "optimised structure and energies. One should as well examine the\n", "orbitals. This is also valid for DFT: Although the Kohn-Sham orbitals\n", "lack, in a strict sense, any physical interpretation, experience shows\n", "that they are *very close* to wavefunction-based single particle\n", "orbitals. Thus, the DFT Kohn-Sham orbitals provide a\n", "useful interpretative tool to visualise changes in the electronic\n", "structure between different species (or in a chemical transformation),\n", "but one should bear in mind that they have to be interpreted with care."]}, {"cell_type": "markdown", "id": "785e01ad", "metadata": {}, "source": ["In Psi4 we will use the `frontier_orbitals` setting, which produces `cube` representations of the frontier molecular orbitals. For closed shell species, the highest occupied (HOMO) and the lowest unoccupied (LUMO) alpha orbitals (ie. $\\psi_\\alpha(r)$) are printed, while for open shell species a total of ($4+M_s$) orbitals are printed ($\\alpha$ and $\\beta$ spin for both lowest virtual (LVMO) and highest doubly occupied orbitals (DOMO), along with all singly occupied (SOMO) orbitals).\n", "The plot below will print $\\alpha$ spin orbitals in red and $\\beta$ spin orbitals in blue.\n", "\n", "You can visualize the cube files using the commands `findCubeFiles(pathToDirectory)` and `showOrbitals(pathToDirectory)`"]}, {"cell_type": "markdown", "id": "4e059a41", "metadata": {}, "source": ["Using `cubeprop` you can also access the electron density (`density`), the basis functions (`basis_functions`), the electrostatic potential (`esp`) and a descriptor calculated from the frontier orbitals which is $f^2(r) = \\rho_{\\text{LUMO}}(r) - \\rho_{\\text{HOMO}}(r)$ (`dual_descriptor`). This descriptor is a good measure of nucleophilicity and electrophilicity and is like both Fukui functions combined."]}, {"cell_type": "code", "execution_count": 6, "id": "50d621dd", "metadata": {}, "outputs": [], "source": ["psi4.set_options({'cubeprop_tasks':['frontier_orbitals']})\n", "psi4.cubeprop(wfn)"]}, {"cell_type": "code", "execution_count": null, "id": "d0d70412", "metadata": {}, "outputs": [], "source": ["orbitals = findCubeFiles('')\n", "show_orbitals(mol=radical)"]}, {"cell_type": "markdown", "id": "a3b4b2be", "metadata": {}, "source": ["### DFT"]}, {"cell_type": "markdown", "id": "fd6c1b6b", "metadata": {}, "source": ["Run the same geometry optimization for two of the following density functionals: BLYP, BP86, PBE, B3LYP, B97-2, M06-L, M06-2X, TPSS, mPW1PW91, wb97x-d. \n", "\n", "For this small system, Hartree-Fock and MP2 were surprisingly fast; however, you may rest assured that for larger molecules and basis sets, all the DFT methods will outperform MP2 in computational efficiency, with some of them even beating Hartree-Fock"]}, {"cell_type": "code", "execution_count": null, "id": "325eb0a1", "metadata": {}, "outputs": [], "source": ["psi4.core.clean_options()\n", "psi4.core.set_output_file(f'radical_opt_{method}.log', False)\n", "psi4.set_options({'reference':''}) # Choose a reference here, for DFT it can be Unrestricted KS (uks), restricted (rks) or restricted open shell (roks)\n", "E_dft, wfn = psi4.optimize(f'method/6-31+G*', molecule=radical, return_wfn=True)"]}, {"cell_type": "code", "execution_count": null, "id": "0343807d", "metadata": {}, "outputs": [], "source": ["# Convert molecule coordinates to numpy array\n", "r_numpy = radical.to_arrays()[0]*hartree2A \n", "\n", "print('DFT: Method') #insert your method here (used just for printing)\n", "print(f'r1: {calculate_bond(r_numpy[0], r_numpy[1]):.3f}')\n", "print(f'r2: {calculate_bond(r_numpy[0], r_numpy[3]):.3f}')\n", "print(f'r3: {calculate_bond(r_numpy[0], r_numpy[2]):.3f}')\n", "print(f'O-N-O angle: {calculate_angle(r_numpy[1], r_numpy[0], r_numpy[2]):.3f}')\n", "print(f'O-N-O angle: {calculate_angle(r_numpy[3], r_numpy[0], r_numpy[2]):.3f}')"]}, {"cell_type": "code", "execution_count": 24, "id": "c178b2db", "metadata": {}, "outputs": [], "source": ["psi4.set_options({'cubeprop_tasks':['frontier_orbitals']})\n", "psi4.cubeprop(wfn)"]}, {"cell_type": "code", "execution_count": null, "id": "3a98ee07", "metadata": {}, "outputs": [], "source": ["orbitals = findCubeFiles()\n", "show_orbitals(mol=radical)"]}, {"cell_type": "markdown", "id": "0d88694f", "metadata": {}, "source": ["## Results comparison\n", "\n", "Now that you have performed the required calculations for HF, MP2 and (some) DFT case, let's compare the performances of the different methods You can find a table with the experimental values for the different geometrical parameters below"]}, {"cell_type": "markdown", "id": "26d8dce6", "metadata": {}, "source": ["|Method:   |  $\\phi_1$ \\[$^\\circ$\\] |  $\\phi_2$ \\[$^\\circ$\\] |  $\\mathbf{r}_1 (O-N)$ \\[\u00c5\\] |  $\\mathbf{r}_2 (O-N)$ \\[\u00c5\\] |  $\\mathbf{r}_3 (O-N)$ \\[\u00c5\\] |  Symmetry |\n", "|----------| ----------------------- | ----------------------- | ---------------------------- |---------------------------- | ---------------------------- | ----------|\n", "| Exp.       |          120         |            120         |              1.24    |          1.24                         |1.24       |       D$_3^h$ |"]}, {"cell_type": "markdown", "id": "5d038ca4", "metadata": {}, "source": [":::{admonition} Exercise 5\n", ":class: exercise\n", "    Fill the above table with the results of your calculations. Compare the performance of the methods in predicting accurate\n", "    structures.     Is there a trend relating the complexity of the exchange-correlation functional (LDA, GGA, hybrid, ...) to the quality of your results?\n", "    \n", "    **Bonus**: For the DFT methods, specify what approximations are\n", "    used in the exchange functional (you may refer to {ref}`dfttheory`). \n", ":::"]}, {"cell_type": "markdown", "id": "5a3f49c7", "metadata": {}, "source": [":::{admonition} Exercise 6\n", ":class: exercise\n", "Take a screenshot of the MP2 and DFT SOMOs. How do the orbitals differ from each other? How does the symmetry of the SOMO relate to the predicted structure?\n", ":::"]}, {"cell_type": "markdown", "id": "c01a7aa4", "metadata": {}, "source": [":::{admonition} Exercise 7\n", ":class: exercise\n", "Explain the difference between static and dynamic correlation. Relate this to the different results you obtained for the nitrate radical. What kind of correlation do HF, MP2 and DFT take into account?\n", ":::"]}, {"cell_type": "markdown", "id": "10ff9d9c", "metadata": {}, "source": [":::{admonition} Exercise 8\n", ":class: exercise\n", "If you needed a highly accurate structure and energy for  NO$_3\\cdot$, which method would you use? Why?\n", ":::"]}], "metadata": {"celltoolbar": "Tags", "hide_input": false, "kernelspec": {"display_name": "Computational Chemistry", "language": "python", "name": "compchem"}, "language_info": {"codemirror_mode": {"name": "ipython", "version": 3}, "file_extension": ".py", "mimetype": "text/x-python", "name": "python", "nbconvert_exporter": "python", "pygments_lexer": "ipython3", "version": "3.8.12"}, "unianalytics_cell_mapping": [["97c36684", "97c36684"], ["28914169", "28914169"], ["aff8393e", "aff8393e"], ["3c036972", "3c036972"], ["f080b9d4", "f080b9d4"], ["9f19a069", "9f19a069"], ["c12810c1", "c12810c1"], ["e47c5190", "e47c5190"], ["d64a469c", "d64a469c"], ["ae735042", "ae735042"], ["44a2ac9c", "44a2ac9c"], ["67b04bbf", "67b04bbf"], ["41358925", "41358925"], ["815a9379", "815a9379"], ["e1dfcda1", "e1dfcda1"], ["4cc5d38e", "4cc5d38e"], ["d95561f3", "d95561f3"], ["a8d1cbb5", "a8d1cbb5"], ["a60f2ba1", "a60f2ba1"], ["785e01ad", "785e01ad"], ["4e059a41", "4e059a41"], ["50d621dd", "50d621dd"], ["d0d70412", "d0d70412"], ["f74d212f", "f74d212f"], ["a3b4b2be", "a3b4b2be"], ["fd6c1b6b", "fd6c1b6b"], ["325eb0a1", "325eb0a1"], ["0343807d", "0343807d"], ["c178b2db", "c178b2db"], ["3a98ee07", "3a98ee07"], ["cf8b051b", "cf8b051b"], ["0d88694f", "0d88694f"], ["26d8dce6", "26d8dce6"], ["5d038ca4", "5d038ca4"], ["ae4ea32e", "ae4ea32e"], ["5a3f49c7", "5a3f49c7"], ["1e24ab2b", "1e24ab2b"], ["c01a7aa4", "c01a7aa4"], ["014bb81b", "014bb81b"], ["10ff9d9c", "10ff9d9c"], ["536f5fae", "536f5fae"]], "unianalytics_notebook_id": "1a4bfc92-5f4a-4371-b002-1a78d463c630", "varInspector": {"cols": {"lenName": 16, "lenType": 16, "lenVar": 40}, "kernels_config": {"python": {"delete_cmd_postfix": "", "delete_cmd_prefix": "del ", "library": "var_list.py", "varRefreshCmd": "print(var_dic_list())"}, "r": {"delete_cmd_postfix": ") ", "delete_cmd_prefix": "rm(", "library": "var_list.r", "varRefreshCmd": "cat(var_dic_list()) "}}, "types_to_exclude": ["module", "function", "builtin_function_or_method", "instance", "_Feature"], "window_display": false}}, "nbformat": 4, "nbformat_minor": 5}